# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetBusinessMetadataResult',
    'AwaitableGetBusinessMetadataResult',
    'get_business_metadata',
    'get_business_metadata_output',
]

@pulumi.output_type
class GetBusinessMetadataResult:
    """
    A collection of values returned by getBusinessMetadata.
    """
    def __init__(__self__, attribute_definitions=None, credentials=None, description=None, id=None, name=None, rest_endpoint=None, schema_registry_cluster=None, version=None):
        if attribute_definitions and not isinstance(attribute_definitions, list):
            raise TypeError("Expected argument 'attribute_definitions' to be a list")
        pulumi.set(__self__, "attribute_definitions", attribute_definitions)
        if credentials and not isinstance(credentials, dict):
            raise TypeError("Expected argument 'credentials' to be a dict")
        pulumi.set(__self__, "credentials", credentials)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if rest_endpoint and not isinstance(rest_endpoint, str):
            raise TypeError("Expected argument 'rest_endpoint' to be a str")
        pulumi.set(__self__, "rest_endpoint", rest_endpoint)
        if schema_registry_cluster and not isinstance(schema_registry_cluster, dict):
            raise TypeError("Expected argument 'schema_registry_cluster' to be a dict")
        pulumi.set(__self__, "schema_registry_cluster", schema_registry_cluster)
        if version and not isinstance(version, int):
            raise TypeError("Expected argument 'version' to be a int")
        pulumi.set(__self__, "version", version)

    @property
    @pulumi.getter(name="attributeDefinitions")
    def attribute_definitions(self) -> Sequence['outputs.GetBusinessMetadataAttributeDefinitionResult']:
        """
        (Optional List) The list of attribute definitions (see [Business Metadata](https://docs.confluent.io/cloud/current/stream-governance/stream-catalog.html#business-metadata-for-schemas) for more details):
        """
        return pulumi.get(self, "attribute_definitions")

    @property
    @pulumi.getter
    def credentials(self) -> Optional['outputs.GetBusinessMetadataCredentialsResult']:
        return pulumi.get(self, "credentials")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        (Optional String) The description of this attribute.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        (Required String) The ID of the Business Metadata, in the format `<Schema Registry cluster ID>/<Business Metadata name>`, for example, `lsrc-8wrx70/PII`.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        (Required String) The name of the attribute.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="restEndpoint")
    def rest_endpoint(self) -> Optional[str]:
        return pulumi.get(self, "rest_endpoint")

    @property
    @pulumi.getter(name="schemaRegistryCluster")
    def schema_registry_cluster(self) -> Optional['outputs.GetBusinessMetadataSchemaRegistryClusterResult']:
        return pulumi.get(self, "schema_registry_cluster")

    @property
    @pulumi.getter
    def version(self) -> int:
        """
        (Required Integer) The version of the Business Metadata, for example, `1`.
        """
        return pulumi.get(self, "version")


class AwaitableGetBusinessMetadataResult(GetBusinessMetadataResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetBusinessMetadataResult(
            attribute_definitions=self.attribute_definitions,
            credentials=self.credentials,
            description=self.description,
            id=self.id,
            name=self.name,
            rest_endpoint=self.rest_endpoint,
            schema_registry_cluster=self.schema_registry_cluster,
            version=self.version)


def get_business_metadata(credentials: Optional[Union['GetBusinessMetadataCredentialsArgs', 'GetBusinessMetadataCredentialsArgsDict']] = None,
                          name: Optional[str] = None,
                          rest_endpoint: Optional[str] = None,
                          schema_registry_cluster: Optional[Union['GetBusinessMetadataSchemaRegistryClusterArgs', 'GetBusinessMetadataSchemaRegistryClusterArgsDict']] = None,
                          opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetBusinessMetadataResult:
    """
    [![General Availability](https://img.shields.io/badge/Lifecycle%20Stage-General%20Availability-%2345c6e8)](https://docs.confluent.io/cloud/current/api.html#section/Versioning/API-Lifecycle-Policy)

    `BusinessMetadata` describes a Business Metadata data source.

    ## Example Usage

    ### Option #1: Manage multiple Schema Registry clusters in the same Pulumi Stack

    ```python
    import pulumi
    import pulumi_confluentcloud as confluentcloud

    pii = confluentcloud.get_business_metadata(schema_registry_cluster={
            "id": essentials["id"],
        },
        rest_endpoint=essentials["restEndpoint"],
        credentials={
            "key": "<Schema Registry API Key for data.confluent_schema_registry_cluster.essentials>",
            "secret": "<Schema Registry API Secret for data.confluent_schema_registry_cluster.essentials>",
        },
        name="PII")
    ```

    ### Option #2: Manage a single Schema Registry cluster in the same Pulumi Stack

    ```python
    import pulumi
    import pulumi_confluentcloud as confluentcloud

    pii = confluentcloud.get_business_metadata(name="PII")
    ```
    > **Note:** We also support `schema_registry_rest_endpoint` instead of `catalog_rest_endpoint` for the time being.


    :param str name: The name of the Business Metadata, for example, `PII`. The name must not be empty and consist of a letter followed by a sequence of letter, number, space, or _ characters.
           
           > **Note:** A Schema Registry API key consists of a key and a secret. Schema Registry API keys are required to interact with Schema Registry clusters in Confluent Cloud. Each Schema Registry API key is valid for one specific Schema Registry cluster.
    :param str rest_endpoint: The REST endpoint of the Schema Registry cluster, for example, `https://psrc-00000.us-central1.gcp.confluent.cloud:443`).
    """
    __args__ = dict()
    __args__['credentials'] = credentials
    __args__['name'] = name
    __args__['restEndpoint'] = rest_endpoint
    __args__['schemaRegistryCluster'] = schema_registry_cluster
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('confluentcloud:index/getBusinessMetadata:getBusinessMetadata', __args__, opts=opts, typ=GetBusinessMetadataResult).value

    return AwaitableGetBusinessMetadataResult(
        attribute_definitions=pulumi.get(__ret__, 'attribute_definitions'),
        credentials=pulumi.get(__ret__, 'credentials'),
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        rest_endpoint=pulumi.get(__ret__, 'rest_endpoint'),
        schema_registry_cluster=pulumi.get(__ret__, 'schema_registry_cluster'),
        version=pulumi.get(__ret__, 'version'))
def get_business_metadata_output(credentials: Optional[pulumi.Input[Optional[Union['GetBusinessMetadataCredentialsArgs', 'GetBusinessMetadataCredentialsArgsDict']]]] = None,
                                 name: Optional[pulumi.Input[str]] = None,
                                 rest_endpoint: Optional[pulumi.Input[Optional[str]]] = None,
                                 schema_registry_cluster: Optional[pulumi.Input[Optional[Union['GetBusinessMetadataSchemaRegistryClusterArgs', 'GetBusinessMetadataSchemaRegistryClusterArgsDict']]]] = None,
                                 opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetBusinessMetadataResult]:
    """
    [![General Availability](https://img.shields.io/badge/Lifecycle%20Stage-General%20Availability-%2345c6e8)](https://docs.confluent.io/cloud/current/api.html#section/Versioning/API-Lifecycle-Policy)

    `BusinessMetadata` describes a Business Metadata data source.

    ## Example Usage

    ### Option #1: Manage multiple Schema Registry clusters in the same Pulumi Stack

    ```python
    import pulumi
    import pulumi_confluentcloud as confluentcloud

    pii = confluentcloud.get_business_metadata(schema_registry_cluster={
            "id": essentials["id"],
        },
        rest_endpoint=essentials["restEndpoint"],
        credentials={
            "key": "<Schema Registry API Key for data.confluent_schema_registry_cluster.essentials>",
            "secret": "<Schema Registry API Secret for data.confluent_schema_registry_cluster.essentials>",
        },
        name="PII")
    ```

    ### Option #2: Manage a single Schema Registry cluster in the same Pulumi Stack

    ```python
    import pulumi
    import pulumi_confluentcloud as confluentcloud

    pii = confluentcloud.get_business_metadata(name="PII")
    ```
    > **Note:** We also support `schema_registry_rest_endpoint` instead of `catalog_rest_endpoint` for the time being.


    :param str name: The name of the Business Metadata, for example, `PII`. The name must not be empty and consist of a letter followed by a sequence of letter, number, space, or _ characters.
           
           > **Note:** A Schema Registry API key consists of a key and a secret. Schema Registry API keys are required to interact with Schema Registry clusters in Confluent Cloud. Each Schema Registry API key is valid for one specific Schema Registry cluster.
    :param str rest_endpoint: The REST endpoint of the Schema Registry cluster, for example, `https://psrc-00000.us-central1.gcp.confluent.cloud:443`).
    """
    __args__ = dict()
    __args__['credentials'] = credentials
    __args__['name'] = name
    __args__['restEndpoint'] = rest_endpoint
    __args__['schemaRegistryCluster'] = schema_registry_cluster
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('confluentcloud:index/getBusinessMetadata:getBusinessMetadata', __args__, opts=opts, typ=GetBusinessMetadataResult)
    return __ret__.apply(lambda __response__: GetBusinessMetadataResult(
        attribute_definitions=pulumi.get(__response__, 'attribute_definitions'),
        credentials=pulumi.get(__response__, 'credentials'),
        description=pulumi.get(__response__, 'description'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        rest_endpoint=pulumi.get(__response__, 'rest_endpoint'),
        schema_registry_cluster=pulumi.get(__response__, 'schema_registry_cluster'),
        version=pulumi.get(__response__, 'version')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['SchemaExporterArgs', 'SchemaExporter']

@pulumi.input_type
class SchemaExporterArgs:
    def __init__(__self__, *,
                 destination_schema_registry_cluster: pulumi.Input['SchemaExporterDestinationSchemaRegistryClusterArgs'],
                 config: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 context: Optional[pulumi.Input[str]] = None,
                 context_type: Optional[pulumi.Input[str]] = None,
                 credentials: Optional[pulumi.Input['SchemaExporterCredentialsArgs']] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 reset_on_update: Optional[pulumi.Input[bool]] = None,
                 rest_endpoint: Optional[pulumi.Input[str]] = None,
                 schema_registry_cluster: Optional[pulumi.Input['SchemaExporterSchemaRegistryClusterArgs']] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 subject_rename_format: Optional[pulumi.Input[str]] = None,
                 subjects: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        """
        The set of arguments for constructing a SchemaExporter resource.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] config: Block for custom *nonsensitive* configuration properties:
        :param pulumi.Input[str] context: Customized context of the exporter if `context_type` is set to `CUSTOM`.
        :param pulumi.Input[str] context_type: Context type of the exporter. Accepted values are: `CUSTOM`, `NONE` or `AUTO`. Defaults to `AUTO`.
        :param pulumi.Input['SchemaExporterCredentialsArgs'] credentials: The Cluster API Credentials.
        :param pulumi.Input[str] name: Name of the Schema Exporter.
        :param pulumi.Input[bool] reset_on_update: The flag to control whether to reset the exporter when updating configs. Defaults to `false`.
        :param pulumi.Input[str] rest_endpoint: The REST endpoint of the Schema Registry cluster, for example, `https://psrc-00000.us-central1.gcp.confluent.cloud:443`).
        :param pulumi.Input[str] status: The status of the schema exporter. Accepted values are: `RUNNING` and `PAUSED`.
        :param pulumi.Input[str] subject_rename_format: Format string for the subject name in the destination cluster, which may contain `${subject}` as a placeholder for the originating subject name. For example, `dc_${subject}` for the subject orders will map to the destination subject name `dc_orders`.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] subjects: Name of each exporter subject.
        """
        pulumi.set(__self__, "destination_schema_registry_cluster", destination_schema_registry_cluster)
        if config is not None:
            pulumi.set(__self__, "config", config)
        if context is not None:
            pulumi.set(__self__, "context", context)
        if context_type is not None:
            pulumi.set(__self__, "context_type", context_type)
        if credentials is not None:
            pulumi.set(__self__, "credentials", credentials)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if reset_on_update is not None:
            pulumi.set(__self__, "reset_on_update", reset_on_update)
        if rest_endpoint is not None:
            pulumi.set(__self__, "rest_endpoint", rest_endpoint)
        if schema_registry_cluster is not None:
            pulumi.set(__self__, "schema_registry_cluster", schema_registry_cluster)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if subject_rename_format is not None:
            pulumi.set(__self__, "subject_rename_format", subject_rename_format)
        if subjects is not None:
            pulumi.set(__self__, "subjects", subjects)

    @property
    @pulumi.getter(name="destinationSchemaRegistryCluster")
    def destination_schema_registry_cluster(self) -> pulumi.Input['SchemaExporterDestinationSchemaRegistryClusterArgs']:
        return pulumi.get(self, "destination_schema_registry_cluster")

    @destination_schema_registry_cluster.setter
    def destination_schema_registry_cluster(self, value: pulumi.Input['SchemaExporterDestinationSchemaRegistryClusterArgs']):
        pulumi.set(self, "destination_schema_registry_cluster", value)

    @property
    @pulumi.getter
    def config(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        Block for custom *nonsensitive* configuration properties:
        """
        return pulumi.get(self, "config")

    @config.setter
    def config(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "config", value)

    @property
    @pulumi.getter
    def context(self) -> Optional[pulumi.Input[str]]:
        """
        Customized context of the exporter if `context_type` is set to `CUSTOM`.
        """
        return pulumi.get(self, "context")

    @context.setter
    def context(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "context", value)

    @property
    @pulumi.getter(name="contextType")
    def context_type(self) -> Optional[pulumi.Input[str]]:
        """
        Context type of the exporter. Accepted values are: `CUSTOM`, `NONE` or `AUTO`. Defaults to `AUTO`.
        """
        return pulumi.get(self, "context_type")

    @context_type.setter
    def context_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "context_type", value)

    @property
    @pulumi.getter
    def credentials(self) -> Optional[pulumi.Input['SchemaExporterCredentialsArgs']]:
        """
        The Cluster API Credentials.
        """
        return pulumi.get(self, "credentials")

    @credentials.setter
    def credentials(self, value: Optional[pulumi.Input['SchemaExporterCredentialsArgs']]):
        pulumi.set(self, "credentials", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the Schema Exporter.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="resetOnUpdate")
    def reset_on_update(self) -> Optional[pulumi.Input[bool]]:
        """
        The flag to control whether to reset the exporter when updating configs. Defaults to `false`.
        """
        return pulumi.get(self, "reset_on_update")

    @reset_on_update.setter
    def reset_on_update(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "reset_on_update", value)

    @property
    @pulumi.getter(name="restEndpoint")
    def rest_endpoint(self) -> Optional[pulumi.Input[str]]:
        """
        The REST endpoint of the Schema Registry cluster, for example, `https://psrc-00000.us-central1.gcp.confluent.cloud:443`).
        """
        return pulumi.get(self, "rest_endpoint")

    @rest_endpoint.setter
    def rest_endpoint(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "rest_endpoint", value)

    @property
    @pulumi.getter(name="schemaRegistryCluster")
    def schema_registry_cluster(self) -> Optional[pulumi.Input['SchemaExporterSchemaRegistryClusterArgs']]:
        return pulumi.get(self, "schema_registry_cluster")

    @schema_registry_cluster.setter
    def schema_registry_cluster(self, value: Optional[pulumi.Input['SchemaExporterSchemaRegistryClusterArgs']]):
        pulumi.set(self, "schema_registry_cluster", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        The status of the schema exporter. Accepted values are: `RUNNING` and `PAUSED`.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="subjectRenameFormat")
    def subject_rename_format(self) -> Optional[pulumi.Input[str]]:
        """
        Format string for the subject name in the destination cluster, which may contain `${subject}` as a placeholder for the originating subject name. For example, `dc_${subject}` for the subject orders will map to the destination subject name `dc_orders`.
        """
        return pulumi.get(self, "subject_rename_format")

    @subject_rename_format.setter
    def subject_rename_format(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "subject_rename_format", value)

    @property
    @pulumi.getter
    def subjects(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Name of each exporter subject.
        """
        return pulumi.get(self, "subjects")

    @subjects.setter
    def subjects(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "subjects", value)


@pulumi.input_type
class _SchemaExporterState:
    def __init__(__self__, *,
                 config: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 context: Optional[pulumi.Input[str]] = None,
                 context_type: Optional[pulumi.Input[str]] = None,
                 credentials: Optional[pulumi.Input['SchemaExporterCredentialsArgs']] = None,
                 destination_schema_registry_cluster: Optional[pulumi.Input['SchemaExporterDestinationSchemaRegistryClusterArgs']] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 reset_on_update: Optional[pulumi.Input[bool]] = None,
                 rest_endpoint: Optional[pulumi.Input[str]] = None,
                 schema_registry_cluster: Optional[pulumi.Input['SchemaExporterSchemaRegistryClusterArgs']] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 subject_rename_format: Optional[pulumi.Input[str]] = None,
                 subjects: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        """
        Input properties used for looking up and filtering SchemaExporter resources.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] config: Block for custom *nonsensitive* configuration properties:
        :param pulumi.Input[str] context: Customized context of the exporter if `context_type` is set to `CUSTOM`.
        :param pulumi.Input[str] context_type: Context type of the exporter. Accepted values are: `CUSTOM`, `NONE` or `AUTO`. Defaults to `AUTO`.
        :param pulumi.Input['SchemaExporterCredentialsArgs'] credentials: The Cluster API Credentials.
        :param pulumi.Input[str] name: Name of the Schema Exporter.
        :param pulumi.Input[bool] reset_on_update: The flag to control whether to reset the exporter when updating configs. Defaults to `false`.
        :param pulumi.Input[str] rest_endpoint: The REST endpoint of the Schema Registry cluster, for example, `https://psrc-00000.us-central1.gcp.confluent.cloud:443`).
        :param pulumi.Input[str] status: The status of the schema exporter. Accepted values are: `RUNNING` and `PAUSED`.
        :param pulumi.Input[str] subject_rename_format: Format string for the subject name in the destination cluster, which may contain `${subject}` as a placeholder for the originating subject name. For example, `dc_${subject}` for the subject orders will map to the destination subject name `dc_orders`.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] subjects: Name of each exporter subject.
        """
        if config is not None:
            pulumi.set(__self__, "config", config)
        if context is not None:
            pulumi.set(__self__, "context", context)
        if context_type is not None:
            pulumi.set(__self__, "context_type", context_type)
        if credentials is not None:
            pulumi.set(__self__, "credentials", credentials)
        if destination_schema_registry_cluster is not None:
            pulumi.set(__self__, "destination_schema_registry_cluster", destination_schema_registry_cluster)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if reset_on_update is not None:
            pulumi.set(__self__, "reset_on_update", reset_on_update)
        if rest_endpoint is not None:
            pulumi.set(__self__, "rest_endpoint", rest_endpoint)
        if schema_registry_cluster is not None:
            pulumi.set(__self__, "schema_registry_cluster", schema_registry_cluster)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if subject_rename_format is not None:
            pulumi.set(__self__, "subject_rename_format", subject_rename_format)
        if subjects is not None:
            pulumi.set(__self__, "subjects", subjects)

    @property
    @pulumi.getter
    def config(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        Block for custom *nonsensitive* configuration properties:
        """
        return pulumi.get(self, "config")

    @config.setter
    def config(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "config", value)

    @property
    @pulumi.getter
    def context(self) -> Optional[pulumi.Input[str]]:
        """
        Customized context of the exporter if `context_type` is set to `CUSTOM`.
        """
        return pulumi.get(self, "context")

    @context.setter
    def context(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "context", value)

    @property
    @pulumi.getter(name="contextType")
    def context_type(self) -> Optional[pulumi.Input[str]]:
        """
        Context type of the exporter. Accepted values are: `CUSTOM`, `NONE` or `AUTO`. Defaults to `AUTO`.
        """
        return pulumi.get(self, "context_type")

    @context_type.setter
    def context_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "context_type", value)

    @property
    @pulumi.getter
    def credentials(self) -> Optional[pulumi.Input['SchemaExporterCredentialsArgs']]:
        """
        The Cluster API Credentials.
        """
        return pulumi.get(self, "credentials")

    @credentials.setter
    def credentials(self, value: Optional[pulumi.Input['SchemaExporterCredentialsArgs']]):
        pulumi.set(self, "credentials", value)

    @property
    @pulumi.getter(name="destinationSchemaRegistryCluster")
    def destination_schema_registry_cluster(self) -> Optional[pulumi.Input['SchemaExporterDestinationSchemaRegistryClusterArgs']]:
        return pulumi.get(self, "destination_schema_registry_cluster")

    @destination_schema_registry_cluster.setter
    def destination_schema_registry_cluster(self, value: Optional[pulumi.Input['SchemaExporterDestinationSchemaRegistryClusterArgs']]):
        pulumi.set(self, "destination_schema_registry_cluster", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the Schema Exporter.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="resetOnUpdate")
    def reset_on_update(self) -> Optional[pulumi.Input[bool]]:
        """
        The flag to control whether to reset the exporter when updating configs. Defaults to `false`.
        """
        return pulumi.get(self, "reset_on_update")

    @reset_on_update.setter
    def reset_on_update(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "reset_on_update", value)

    @property
    @pulumi.getter(name="restEndpoint")
    def rest_endpoint(self) -> Optional[pulumi.Input[str]]:
        """
        The REST endpoint of the Schema Registry cluster, for example, `https://psrc-00000.us-central1.gcp.confluent.cloud:443`).
        """
        return pulumi.get(self, "rest_endpoint")

    @rest_endpoint.setter
    def rest_endpoint(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "rest_endpoint", value)

    @property
    @pulumi.getter(name="schemaRegistryCluster")
    def schema_registry_cluster(self) -> Optional[pulumi.Input['SchemaExporterSchemaRegistryClusterArgs']]:
        return pulumi.get(self, "schema_registry_cluster")

    @schema_registry_cluster.setter
    def schema_registry_cluster(self, value: Optional[pulumi.Input['SchemaExporterSchemaRegistryClusterArgs']]):
        pulumi.set(self, "schema_registry_cluster", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        The status of the schema exporter. Accepted values are: `RUNNING` and `PAUSED`.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="subjectRenameFormat")
    def subject_rename_format(self) -> Optional[pulumi.Input[str]]:
        """
        Format string for the subject name in the destination cluster, which may contain `${subject}` as a placeholder for the originating subject name. For example, `dc_${subject}` for the subject orders will map to the destination subject name `dc_orders`.
        """
        return pulumi.get(self, "subject_rename_format")

    @subject_rename_format.setter
    def subject_rename_format(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "subject_rename_format", value)

    @property
    @pulumi.getter
    def subjects(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Name of each exporter subject.
        """
        return pulumi.get(self, "subjects")

    @subjects.setter
    def subjects(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "subjects", value)


class SchemaExporter(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 config: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 context: Optional[pulumi.Input[str]] = None,
                 context_type: Optional[pulumi.Input[str]] = None,
                 credentials: Optional[pulumi.Input[Union['SchemaExporterCredentialsArgs', 'SchemaExporterCredentialsArgsDict']]] = None,
                 destination_schema_registry_cluster: Optional[pulumi.Input[Union['SchemaExporterDestinationSchemaRegistryClusterArgs', 'SchemaExporterDestinationSchemaRegistryClusterArgsDict']]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 reset_on_update: Optional[pulumi.Input[bool]] = None,
                 rest_endpoint: Optional[pulumi.Input[str]] = None,
                 schema_registry_cluster: Optional[pulumi.Input[Union['SchemaExporterSchemaRegistryClusterArgs', 'SchemaExporterSchemaRegistryClusterArgsDict']]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 subject_rename_format: Optional[pulumi.Input[str]] = None,
                 subjects: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 __props__=None):
        """
        [![General Availability](https://img.shields.io/badge/Lifecycle%20Stage-General%20Availability-%2345c6e8)](https://docs.confluent.io/cloud/current/api.html#section/Versioning/API-Lifecycle-Policy)

        `SchemaExporter` provides a Schema Exporter resource that enables creating, editing, and deleting Schema Exporters on Confluent Cloud.

        ## Example Usage

        ### Option #1: Manage multiple Schema Registry clusters in the same Pulumi Stack

        ```python
        import pulumi
        import pulumi_confluentcloud as confluentcloud

        main = confluentcloud.SchemaExporter("main",
            schema_registry_cluster={
                "id": essentials["id"],
            },
            rest_endpoint=essentials["restEndpoint"],
            credentials={
                "key": "<Schema Registry API Key for data.confluent_schema_registry_cluster.essentials>",
                "secret": "<Schema Registry API Secret for data.confluent_schema_registry_cluster.essentials>",
            },
            name="test-exporter",
            subjects=["foo"],
            destination_schema_registry_cluster={
                "rest_endpoint": destination["restEndpoint"],
                "credentials": {
                    "key": "<Schema Registry API Key for data.confluent_schema_registry_cluster.destination>",
                    "secret": "<Schema Registry API Secret for data.confluent_schema_registry_cluster.destination>",
                },
            })
        ```

        ### Option #2: Manage a single Schema Registry cluster in the same Pulumi Stack

        ```python
        import pulumi
        import pulumi_confluentcloud as confluentcloud

        main = confluentcloud.SchemaExporter("main",
            name="test-exporter",
            subjects=["foo"],
            destination_schema_registry_cluster={
                "rest_endpoint": destination["restEndpoint"],
                "credentials": {
                    "key": "<Schema Registry API Key for data.confluent_schema_registry_cluster.destination>",
                    "secret": "<Schema Registry API Secret for data.confluent_schema_registry_cluster.destination>",
                },
            })
        ```

        ## Import

        You can import a Schema Exporter by using the Schema Registry cluster ID, Schema Exporter name in the format `<Schema Registry cluster ID>/<Schema Exporter name>`, for example:

        $ export IMPORT_SCHEMA_REGISTRY_ID="<schema_registry_cluster_id>"

        $ export IMPORT_SCHEMA_REGISTRY_API_KEY="<schema_registry_api_key>"

        $ export IMPORT_SCHEMA_REGISTRY_API_SECRET="<schema_registry_api_secret>"

        $ export IMPORT_SCHEMA_REGISTRY_REST_ENDPOINT="<schema_registry_rest_endpoint>"

        ```sh
        $ pulumi import confluentcloud:index/schemaExporter:SchemaExporter main lsrc-8wrx70/test-exporter
        ```

        !> **Warning:** Do not forget to delete terminal command history afterwards for security purposes.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] config: Block for custom *nonsensitive* configuration properties:
        :param pulumi.Input[str] context: Customized context of the exporter if `context_type` is set to `CUSTOM`.
        :param pulumi.Input[str] context_type: Context type of the exporter. Accepted values are: `CUSTOM`, `NONE` or `AUTO`. Defaults to `AUTO`.
        :param pulumi.Input[Union['SchemaExporterCredentialsArgs', 'SchemaExporterCredentialsArgsDict']] credentials: The Cluster API Credentials.
        :param pulumi.Input[str] name: Name of the Schema Exporter.
        :param pulumi.Input[bool] reset_on_update: The flag to control whether to reset the exporter when updating configs. Defaults to `false`.
        :param pulumi.Input[str] rest_endpoint: The REST endpoint of the Schema Registry cluster, for example, `https://psrc-00000.us-central1.gcp.confluent.cloud:443`).
        :param pulumi.Input[str] status: The status of the schema exporter. Accepted values are: `RUNNING` and `PAUSED`.
        :param pulumi.Input[str] subject_rename_format: Format string for the subject name in the destination cluster, which may contain `${subject}` as a placeholder for the originating subject name. For example, `dc_${subject}` for the subject orders will map to the destination subject name `dc_orders`.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] subjects: Name of each exporter subject.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SchemaExporterArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        [![General Availability](https://img.shields.io/badge/Lifecycle%20Stage-General%20Availability-%2345c6e8)](https://docs.confluent.io/cloud/current/api.html#section/Versioning/API-Lifecycle-Policy)

        `SchemaExporter` provides a Schema Exporter resource that enables creating, editing, and deleting Schema Exporters on Confluent Cloud.

        ## Example Usage

        ### Option #1: Manage multiple Schema Registry clusters in the same Pulumi Stack

        ```python
        import pulumi
        import pulumi_confluentcloud as confluentcloud

        main = confluentcloud.SchemaExporter("main",
            schema_registry_cluster={
                "id": essentials["id"],
            },
            rest_endpoint=essentials["restEndpoint"],
            credentials={
                "key": "<Schema Registry API Key for data.confluent_schema_registry_cluster.essentials>",
                "secret": "<Schema Registry API Secret for data.confluent_schema_registry_cluster.essentials>",
            },
            name="test-exporter",
            subjects=["foo"],
            destination_schema_registry_cluster={
                "rest_endpoint": destination["restEndpoint"],
                "credentials": {
                    "key": "<Schema Registry API Key for data.confluent_schema_registry_cluster.destination>",
                    "secret": "<Schema Registry API Secret for data.confluent_schema_registry_cluster.destination>",
                },
            })
        ```

        ### Option #2: Manage a single Schema Registry cluster in the same Pulumi Stack

        ```python
        import pulumi
        import pulumi_confluentcloud as confluentcloud

        main = confluentcloud.SchemaExporter("main",
            name="test-exporter",
            subjects=["foo"],
            destination_schema_registry_cluster={
                "rest_endpoint": destination["restEndpoint"],
                "credentials": {
                    "key": "<Schema Registry API Key for data.confluent_schema_registry_cluster.destination>",
                    "secret": "<Schema Registry API Secret for data.confluent_schema_registry_cluster.destination>",
                },
            })
        ```

        ## Import

        You can import a Schema Exporter by using the Schema Registry cluster ID, Schema Exporter name in the format `<Schema Registry cluster ID>/<Schema Exporter name>`, for example:

        $ export IMPORT_SCHEMA_REGISTRY_ID="<schema_registry_cluster_id>"

        $ export IMPORT_SCHEMA_REGISTRY_API_KEY="<schema_registry_api_key>"

        $ export IMPORT_SCHEMA_REGISTRY_API_SECRET="<schema_registry_api_secret>"

        $ export IMPORT_SCHEMA_REGISTRY_REST_ENDPOINT="<schema_registry_rest_endpoint>"

        ```sh
        $ pulumi import confluentcloud:index/schemaExporter:SchemaExporter main lsrc-8wrx70/test-exporter
        ```

        !> **Warning:** Do not forget to delete terminal command history afterwards for security purposes.

        :param str resource_name: The name of the resource.
        :param SchemaExporterArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SchemaExporterArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 config: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 context: Optional[pulumi.Input[str]] = None,
                 context_type: Optional[pulumi.Input[str]] = None,
                 credentials: Optional[pulumi.Input[Union['SchemaExporterCredentialsArgs', 'SchemaExporterCredentialsArgsDict']]] = None,
                 destination_schema_registry_cluster: Optional[pulumi.Input[Union['SchemaExporterDestinationSchemaRegistryClusterArgs', 'SchemaExporterDestinationSchemaRegistryClusterArgsDict']]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 reset_on_update: Optional[pulumi.Input[bool]] = None,
                 rest_endpoint: Optional[pulumi.Input[str]] = None,
                 schema_registry_cluster: Optional[pulumi.Input[Union['SchemaExporterSchemaRegistryClusterArgs', 'SchemaExporterSchemaRegistryClusterArgsDict']]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 subject_rename_format: Optional[pulumi.Input[str]] = None,
                 subjects: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SchemaExporterArgs.__new__(SchemaExporterArgs)

            __props__.__dict__["config"] = config
            __props__.__dict__["context"] = context
            __props__.__dict__["context_type"] = context_type
            __props__.__dict__["credentials"] = None if credentials is None else pulumi.Output.secret(credentials)
            if destination_schema_registry_cluster is None and not opts.urn:
                raise TypeError("Missing required property 'destination_schema_registry_cluster'")
            __props__.__dict__["destination_schema_registry_cluster"] = destination_schema_registry_cluster
            __props__.__dict__["name"] = name
            __props__.__dict__["reset_on_update"] = reset_on_update
            __props__.__dict__["rest_endpoint"] = rest_endpoint
            __props__.__dict__["schema_registry_cluster"] = schema_registry_cluster
            __props__.__dict__["status"] = status
            __props__.__dict__["subject_rename_format"] = subject_rename_format
            __props__.__dict__["subjects"] = subjects
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["credentials"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(SchemaExporter, __self__).__init__(
            'confluentcloud:index/schemaExporter:SchemaExporter',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            config: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
            context: Optional[pulumi.Input[str]] = None,
            context_type: Optional[pulumi.Input[str]] = None,
            credentials: Optional[pulumi.Input[Union['SchemaExporterCredentialsArgs', 'SchemaExporterCredentialsArgsDict']]] = None,
            destination_schema_registry_cluster: Optional[pulumi.Input[Union['SchemaExporterDestinationSchemaRegistryClusterArgs', 'SchemaExporterDestinationSchemaRegistryClusterArgsDict']]] = None,
            name: Optional[pulumi.Input[str]] = None,
            reset_on_update: Optional[pulumi.Input[bool]] = None,
            rest_endpoint: Optional[pulumi.Input[str]] = None,
            schema_registry_cluster: Optional[pulumi.Input[Union['SchemaExporterSchemaRegistryClusterArgs', 'SchemaExporterSchemaRegistryClusterArgsDict']]] = None,
            status: Optional[pulumi.Input[str]] = None,
            subject_rename_format: Optional[pulumi.Input[str]] = None,
            subjects: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None) -> 'SchemaExporter':
        """
        Get an existing SchemaExporter resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] config: Block for custom *nonsensitive* configuration properties:
        :param pulumi.Input[str] context: Customized context of the exporter if `context_type` is set to `CUSTOM`.
        :param pulumi.Input[str] context_type: Context type of the exporter. Accepted values are: `CUSTOM`, `NONE` or `AUTO`. Defaults to `AUTO`.
        :param pulumi.Input[Union['SchemaExporterCredentialsArgs', 'SchemaExporterCredentialsArgsDict']] credentials: The Cluster API Credentials.
        :param pulumi.Input[str] name: Name of the Schema Exporter.
        :param pulumi.Input[bool] reset_on_update: The flag to control whether to reset the exporter when updating configs. Defaults to `false`.
        :param pulumi.Input[str] rest_endpoint: The REST endpoint of the Schema Registry cluster, for example, `https://psrc-00000.us-central1.gcp.confluent.cloud:443`).
        :param pulumi.Input[str] status: The status of the schema exporter. Accepted values are: `RUNNING` and `PAUSED`.
        :param pulumi.Input[str] subject_rename_format: Format string for the subject name in the destination cluster, which may contain `${subject}` as a placeholder for the originating subject name. For example, `dc_${subject}` for the subject orders will map to the destination subject name `dc_orders`.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] subjects: Name of each exporter subject.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SchemaExporterState.__new__(_SchemaExporterState)

        __props__.__dict__["config"] = config
        __props__.__dict__["context"] = context
        __props__.__dict__["context_type"] = context_type
        __props__.__dict__["credentials"] = credentials
        __props__.__dict__["destination_schema_registry_cluster"] = destination_schema_registry_cluster
        __props__.__dict__["name"] = name
        __props__.__dict__["reset_on_update"] = reset_on_update
        __props__.__dict__["rest_endpoint"] = rest_endpoint
        __props__.__dict__["schema_registry_cluster"] = schema_registry_cluster
        __props__.__dict__["status"] = status
        __props__.__dict__["subject_rename_format"] = subject_rename_format
        __props__.__dict__["subjects"] = subjects
        return SchemaExporter(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def config(self) -> pulumi.Output[Mapping[str, str]]:
        """
        Block for custom *nonsensitive* configuration properties:
        """
        return pulumi.get(self, "config")

    @property
    @pulumi.getter
    def context(self) -> pulumi.Output[str]:
        """
        Customized context of the exporter if `context_type` is set to `CUSTOM`.
        """
        return pulumi.get(self, "context")

    @property
    @pulumi.getter(name="contextType")
    def context_type(self) -> pulumi.Output[str]:
        """
        Context type of the exporter. Accepted values are: `CUSTOM`, `NONE` or `AUTO`. Defaults to `AUTO`.
        """
        return pulumi.get(self, "context_type")

    @property
    @pulumi.getter
    def credentials(self) -> pulumi.Output[Optional['outputs.SchemaExporterCredentials']]:
        """
        The Cluster API Credentials.
        """
        return pulumi.get(self, "credentials")

    @property
    @pulumi.getter(name="destinationSchemaRegistryCluster")
    def destination_schema_registry_cluster(self) -> pulumi.Output['outputs.SchemaExporterDestinationSchemaRegistryCluster']:
        return pulumi.get(self, "destination_schema_registry_cluster")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        Name of the Schema Exporter.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="resetOnUpdate")
    def reset_on_update(self) -> pulumi.Output[Optional[bool]]:
        """
        The flag to control whether to reset the exporter when updating configs. Defaults to `false`.
        """
        return pulumi.get(self, "reset_on_update")

    @property
    @pulumi.getter(name="restEndpoint")
    def rest_endpoint(self) -> pulumi.Output[Optional[str]]:
        """
        The REST endpoint of the Schema Registry cluster, for example, `https://psrc-00000.us-central1.gcp.confluent.cloud:443`).
        """
        return pulumi.get(self, "rest_endpoint")

    @property
    @pulumi.getter(name="schemaRegistryCluster")
    def schema_registry_cluster(self) -> pulumi.Output[Optional['outputs.SchemaExporterSchemaRegistryCluster']]:
        return pulumi.get(self, "schema_registry_cluster")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        The status of the schema exporter. Accepted values are: `RUNNING` and `PAUSED`.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="subjectRenameFormat")
    def subject_rename_format(self) -> pulumi.Output[str]:
        """
        Format string for the subject name in the destination cluster, which may contain `${subject}` as a placeholder for the originating subject name. For example, `dc_${subject}` for the subject orders will map to the destination subject name `dc_orders`.
        """
        return pulumi.get(self, "subject_rename_format")

    @property
    @pulumi.getter
    def subjects(self) -> pulumi.Output[Sequence[str]]:
        """
        Name of each exporter subject.
        """
        return pulumi.get(self, "subjects")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetUserResult',
    'AwaitableGetUserResult',
    'get_user',
    'get_user_output',
]

@pulumi.output_type
class GetUserResult:
    """
    A collection of values returned by getUser.
    """
    def __init__(__self__, api_version=None, email=None, full_name=None, id=None, kind=None):
        if api_version and not isinstance(api_version, str):
            raise TypeError("Expected argument 'api_version' to be a str")
        pulumi.set(__self__, "api_version", api_version)
        if email and not isinstance(email, str):
            raise TypeError("Expected argument 'email' to be a str")
        pulumi.set(__self__, "email", email)
        if full_name and not isinstance(full_name, str):
            raise TypeError("Expected argument 'full_name' to be a str")
        pulumi.set(__self__, "full_name", full_name)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if kind and not isinstance(kind, str):
            raise TypeError("Expected argument 'kind' to be a str")
        pulumi.set(__self__, "kind", kind)

    @property
    @pulumi.getter(name="apiVersion")
    def api_version(self) -> str:
        """
        (Required String) An API Version of the schema version of the User.
        """
        return pulumi.get(self, "api_version")

    @property
    @pulumi.getter
    def email(self) -> str:
        """
        (Required String) The email address of the User.
        """
        return pulumi.get(self, "email")

    @property
    @pulumi.getter(name="fullName")
    def full_name(self) -> str:
        """
        (Required String) The full name of the User.
        """
        return pulumi.get(self, "full_name")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        (Required String) The ID of the User, for example, `u-abc123`.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def kind(self) -> str:
        """
        (Required String) A kind of the User.
        """
        return pulumi.get(self, "kind")


class AwaitableGetUserResult(GetUserResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetUserResult(
            api_version=self.api_version,
            email=self.email,
            full_name=self.full_name,
            id=self.id,
            kind=self.kind)


def get_user(email: Optional[str] = None,
             full_name: Optional[str] = None,
             id: Optional[str] = None,
             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetUserResult:
    """
    [![General Availability](https://img.shields.io/badge/Lifecycle%20Stage-General%20Availability-%2345c6e8)](https://docs.confluent.io/cloud/current/api.html#section/Versioning/API-Lifecycle-Policy)

    `get_user` describes a User data source.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_confluentcloud as confluentcloud

    example_using_id = confluentcloud.get_user(id="u-abc123")
    pulumi.export("exampleUsingId", example_using_id)
    example_using_email = confluentcloud.get_user(email="test123@gmail.com")
    test_env = confluentcloud.Environment("test-env", display_name=f"env_for_{example_using_id.full_name}")
    standard_cluster_on_aws = confluentcloud.KafkaCluster("standard-cluster-on-aws",
        display_name="standard_kafka_cluster_on_aws",
        availability="SINGLE_ZONE",
        cloud="AWS",
        region="us-west-2",
        standard={},
        environment={
            "id": test_env.id,
        })
    test_role_binding = confluentcloud.RoleBinding("test-role-binding",
        principal=f"User:{example_using_email.id}",
        role_name="CloudClusterAdmin",
        crn_pattern=standard_cluster_on_aws.rbac_crn)
    example_using_full_name = confluentcloud.get_user(full_name="John Doe")
    ```


    :param str email: The email address of the User.
           
           > **Note:** Exactly one from the `id`, `full_name` and `email` attributes must be specified.
    :param str full_name: The full name of the User.
    :param str id: The ID of the User (e.g., `u-abc123`).
    """
    __args__ = dict()
    __args__['email'] = email
    __args__['fullName'] = full_name
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('confluentcloud:index/getUser:getUser', __args__, opts=opts, typ=GetUserResult).value

    return AwaitableGetUserResult(
        api_version=pulumi.get(__ret__, 'api_version'),
        email=pulumi.get(__ret__, 'email'),
        full_name=pulumi.get(__ret__, 'full_name'),
        id=pulumi.get(__ret__, 'id'),
        kind=pulumi.get(__ret__, 'kind'))
def get_user_output(email: Optional[pulumi.Input[Optional[str]]] = None,
                    full_name: Optional[pulumi.Input[Optional[str]]] = None,
                    id: Optional[pulumi.Input[Optional[str]]] = None,
                    opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetUserResult]:
    """
    [![General Availability](https://img.shields.io/badge/Lifecycle%20Stage-General%20Availability-%2345c6e8)](https://docs.confluent.io/cloud/current/api.html#section/Versioning/API-Lifecycle-Policy)

    `get_user` describes a User data source.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_confluentcloud as confluentcloud

    example_using_id = confluentcloud.get_user(id="u-abc123")
    pulumi.export("exampleUsingId", example_using_id)
    example_using_email = confluentcloud.get_user(email="test123@gmail.com")
    test_env = confluentcloud.Environment("test-env", display_name=f"env_for_{example_using_id.full_name}")
    standard_cluster_on_aws = confluentcloud.KafkaCluster("standard-cluster-on-aws",
        display_name="standard_kafka_cluster_on_aws",
        availability="SINGLE_ZONE",
        cloud="AWS",
        region="us-west-2",
        standard={},
        environment={
            "id": test_env.id,
        })
    test_role_binding = confluentcloud.RoleBinding("test-role-binding",
        principal=f"User:{example_using_email.id}",
        role_name="CloudClusterAdmin",
        crn_pattern=standard_cluster_on_aws.rbac_crn)
    example_using_full_name = confluentcloud.get_user(full_name="John Doe")
    ```


    :param str email: The email address of the User.
           
           > **Note:** Exactly one from the `id`, `full_name` and `email` attributes must be specified.
    :param str full_name: The full name of the User.
    :param str id: The ID of the User (e.g., `u-abc123`).
    """
    __args__ = dict()
    __args__['email'] = email
    __args__['fullName'] = full_name
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('confluentcloud:index/getUser:getUser', __args__, opts=opts, typ=GetUserResult)
    return __ret__.apply(lambda __response__: GetUserResult(
        api_version=pulumi.get(__response__, 'api_version'),
        email=pulumi.get(__response__, 'email'),
        full_name=pulumi.get(__response__, 'full_name'),
        id=pulumi.get(__response__, 'id'),
        kind=pulumi.get(__response__, 'kind')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ConnectorArgs', 'Connector']

@pulumi.input_type
class ConnectorArgs:
    def __init__(__self__, *,
                 config_nonsensitive: pulumi.Input[Mapping[str, pulumi.Input[str]]],
                 environment: pulumi.Input['ConnectorEnvironmentArgs'],
                 kafka_cluster: pulumi.Input['ConnectorKafkaClusterArgs'],
                 config_sensitive: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 offsets: Optional[pulumi.Input[Sequence[pulumi.Input['ConnectorOffsetArgs']]]] = None,
                 status: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a Connector resource.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] config_nonsensitive: Block for custom *nonsensitive* configuration properties that are *not* labelled with "Type: password" under "Configuration Properties" section in [the docs](https://docs.confluent.io/cloud/current/connectors/index.html):
        :param pulumi.Input['ConnectorEnvironmentArgs'] environment: Environment objects represent an isolated namespace for your Confluent resources for organizational purposes.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] config_sensitive: Block for custom *sensitive* configuration properties that are labelled with "Type: password" under "Configuration Properties" section in [the docs](https://docs.confluent.io/cloud/current/connectors/index.html):
        :param pulumi.Input[Sequence[pulumi.Input['ConnectorOffsetArgs']]] offsets: Connector partitions with offsets
        :param pulumi.Input[str] status: The status of the connector (one of `"NONE"`, `"PROVISIONING"`, `"RUNNING"`, `"DEGRADED"`, `"FAILED"`, `"PAUSED"`, `"DELETED"`). Pausing (`"RUNNING" > "PAUSED"`) and resuming (`"PAUSED" > "RUNNING"`) a connector is supported via an update operation.
               
               For more information on connector offset management, see [Manage Offsets for Fully-Managed Connectors in Confluent Cloud](https://docs.confluent.io/cloud/current/connectors/offsets.html).
               
               > **Note:** If there are no _sensitive_ configuration settings for your connector, set `config_sensitive = {}` explicitly.
               
               > **Note:** You may declare sensitive variables for secrets `config_sensitive` block and set them using environment variables (for example, `export TF_VAR_aws_access_key_id="foo"`).
        """
        pulumi.set(__self__, "config_nonsensitive", config_nonsensitive)
        pulumi.set(__self__, "environment", environment)
        pulumi.set(__self__, "kafka_cluster", kafka_cluster)
        if config_sensitive is not None:
            pulumi.set(__self__, "config_sensitive", config_sensitive)
        if offsets is not None:
            pulumi.set(__self__, "offsets", offsets)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="configNonsensitive")
    def config_nonsensitive(self) -> pulumi.Input[Mapping[str, pulumi.Input[str]]]:
        """
        Block for custom *nonsensitive* configuration properties that are *not* labelled with "Type: password" under "Configuration Properties" section in [the docs](https://docs.confluent.io/cloud/current/connectors/index.html):
        """
        return pulumi.get(self, "config_nonsensitive")

    @config_nonsensitive.setter
    def config_nonsensitive(self, value: pulumi.Input[Mapping[str, pulumi.Input[str]]]):
        pulumi.set(self, "config_nonsensitive", value)

    @property
    @pulumi.getter
    def environment(self) -> pulumi.Input['ConnectorEnvironmentArgs']:
        """
        Environment objects represent an isolated namespace for your Confluent resources for organizational purposes.
        """
        return pulumi.get(self, "environment")

    @environment.setter
    def environment(self, value: pulumi.Input['ConnectorEnvironmentArgs']):
        pulumi.set(self, "environment", value)

    @property
    @pulumi.getter(name="kafkaCluster")
    def kafka_cluster(self) -> pulumi.Input['ConnectorKafkaClusterArgs']:
        return pulumi.get(self, "kafka_cluster")

    @kafka_cluster.setter
    def kafka_cluster(self, value: pulumi.Input['ConnectorKafkaClusterArgs']):
        pulumi.set(self, "kafka_cluster", value)

    @property
    @pulumi.getter(name="configSensitive")
    def config_sensitive(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        Block for custom *sensitive* configuration properties that are labelled with "Type: password" under "Configuration Properties" section in [the docs](https://docs.confluent.io/cloud/current/connectors/index.html):
        """
        return pulumi.get(self, "config_sensitive")

    @config_sensitive.setter
    def config_sensitive(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "config_sensitive", value)

    @property
    @pulumi.getter
    def offsets(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ConnectorOffsetArgs']]]]:
        """
        Connector partitions with offsets
        """
        return pulumi.get(self, "offsets")

    @offsets.setter
    def offsets(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ConnectorOffsetArgs']]]]):
        pulumi.set(self, "offsets", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        The status of the connector (one of `"NONE"`, `"PROVISIONING"`, `"RUNNING"`, `"DEGRADED"`, `"FAILED"`, `"PAUSED"`, `"DELETED"`). Pausing (`"RUNNING" > "PAUSED"`) and resuming (`"PAUSED" > "RUNNING"`) a connector is supported via an update operation.

        For more information on connector offset management, see [Manage Offsets for Fully-Managed Connectors in Confluent Cloud](https://docs.confluent.io/cloud/current/connectors/offsets.html).

        > **Note:** If there are no _sensitive_ configuration settings for your connector, set `config_sensitive = {}` explicitly.

        > **Note:** You may declare sensitive variables for secrets `config_sensitive` block and set them using environment variables (for example, `export TF_VAR_aws_access_key_id="foo"`).
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)


@pulumi.input_type
class _ConnectorState:
    def __init__(__self__, *,
                 config_nonsensitive: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 config_sensitive: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 environment: Optional[pulumi.Input['ConnectorEnvironmentArgs']] = None,
                 kafka_cluster: Optional[pulumi.Input['ConnectorKafkaClusterArgs']] = None,
                 offsets: Optional[pulumi.Input[Sequence[pulumi.Input['ConnectorOffsetArgs']]]] = None,
                 status: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Connector resources.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] config_nonsensitive: Block for custom *nonsensitive* configuration properties that are *not* labelled with "Type: password" under "Configuration Properties" section in [the docs](https://docs.confluent.io/cloud/current/connectors/index.html):
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] config_sensitive: Block for custom *sensitive* configuration properties that are labelled with "Type: password" under "Configuration Properties" section in [the docs](https://docs.confluent.io/cloud/current/connectors/index.html):
        :param pulumi.Input['ConnectorEnvironmentArgs'] environment: Environment objects represent an isolated namespace for your Confluent resources for organizational purposes.
        :param pulumi.Input[Sequence[pulumi.Input['ConnectorOffsetArgs']]] offsets: Connector partitions with offsets
        :param pulumi.Input[str] status: The status of the connector (one of `"NONE"`, `"PROVISIONING"`, `"RUNNING"`, `"DEGRADED"`, `"FAILED"`, `"PAUSED"`, `"DELETED"`). Pausing (`"RUNNING" > "PAUSED"`) and resuming (`"PAUSED" > "RUNNING"`) a connector is supported via an update operation.
               
               For more information on connector offset management, see [Manage Offsets for Fully-Managed Connectors in Confluent Cloud](https://docs.confluent.io/cloud/current/connectors/offsets.html).
               
               > **Note:** If there are no _sensitive_ configuration settings for your connector, set `config_sensitive = {}` explicitly.
               
               > **Note:** You may declare sensitive variables for secrets `config_sensitive` block and set them using environment variables (for example, `export TF_VAR_aws_access_key_id="foo"`).
        """
        if config_nonsensitive is not None:
            pulumi.set(__self__, "config_nonsensitive", config_nonsensitive)
        if config_sensitive is not None:
            pulumi.set(__self__, "config_sensitive", config_sensitive)
        if environment is not None:
            pulumi.set(__self__, "environment", environment)
        if kafka_cluster is not None:
            pulumi.set(__self__, "kafka_cluster", kafka_cluster)
        if offsets is not None:
            pulumi.set(__self__, "offsets", offsets)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="configNonsensitive")
    def config_nonsensitive(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        Block for custom *nonsensitive* configuration properties that are *not* labelled with "Type: password" under "Configuration Properties" section in [the docs](https://docs.confluent.io/cloud/current/connectors/index.html):
        """
        return pulumi.get(self, "config_nonsensitive")

    @config_nonsensitive.setter
    def config_nonsensitive(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "config_nonsensitive", value)

    @property
    @pulumi.getter(name="configSensitive")
    def config_sensitive(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        Block for custom *sensitive* configuration properties that are labelled with "Type: password" under "Configuration Properties" section in [the docs](https://docs.confluent.io/cloud/current/connectors/index.html):
        """
        return pulumi.get(self, "config_sensitive")

    @config_sensitive.setter
    def config_sensitive(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "config_sensitive", value)

    @property
    @pulumi.getter
    def environment(self) -> Optional[pulumi.Input['ConnectorEnvironmentArgs']]:
        """
        Environment objects represent an isolated namespace for your Confluent resources for organizational purposes.
        """
        return pulumi.get(self, "environment")

    @environment.setter
    def environment(self, value: Optional[pulumi.Input['ConnectorEnvironmentArgs']]):
        pulumi.set(self, "environment", value)

    @property
    @pulumi.getter(name="kafkaCluster")
    def kafka_cluster(self) -> Optional[pulumi.Input['ConnectorKafkaClusterArgs']]:
        return pulumi.get(self, "kafka_cluster")

    @kafka_cluster.setter
    def kafka_cluster(self, value: Optional[pulumi.Input['ConnectorKafkaClusterArgs']]):
        pulumi.set(self, "kafka_cluster", value)

    @property
    @pulumi.getter
    def offsets(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ConnectorOffsetArgs']]]]:
        """
        Connector partitions with offsets
        """
        return pulumi.get(self, "offsets")

    @offsets.setter
    def offsets(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ConnectorOffsetArgs']]]]):
        pulumi.set(self, "offsets", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        The status of the connector (one of `"NONE"`, `"PROVISIONING"`, `"RUNNING"`, `"DEGRADED"`, `"FAILED"`, `"PAUSED"`, `"DELETED"`). Pausing (`"RUNNING" > "PAUSED"`) and resuming (`"PAUSED" > "RUNNING"`) a connector is supported via an update operation.

        For more information on connector offset management, see [Manage Offsets for Fully-Managed Connectors in Confluent Cloud](https://docs.confluent.io/cloud/current/connectors/offsets.html).

        > **Note:** If there are no _sensitive_ configuration settings for your connector, set `config_sensitive = {}` explicitly.

        > **Note:** You may declare sensitive variables for secrets `config_sensitive` block and set them using environment variables (for example, `export TF_VAR_aws_access_key_id="foo"`).
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)


class Connector(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 config_nonsensitive: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 config_sensitive: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 environment: Optional[pulumi.Input[Union['ConnectorEnvironmentArgs', 'ConnectorEnvironmentArgsDict']]] = None,
                 kafka_cluster: Optional[pulumi.Input[Union['ConnectorKafkaClusterArgs', 'ConnectorKafkaClusterArgsDict']]] = None,
                 offsets: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ConnectorOffsetArgs', 'ConnectorOffsetArgsDict']]]]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        ## Example Usage

        ### Example Managed [Datagen Source Connector](https://docs.confluent.io/cloud/current/connectors/cc-datagen-source.html) that uses a service account to communicate with your Kafka cluster
        ```python
        import pulumi
        import pulumi_confluentcloud as confluentcloud

        # https://github.com/confluentinc/terraform-provider-confluent/tree/master/examples/configurations/connectors/managed-datagen-source-connector
        source = confluentcloud.Connector("source",
            environment={
                "id": staging["id"],
            },
            kafka_cluster={
                "id": basic["id"],
            },
            config_sensitive={},
            config_nonsensitive={
                "connector.class": "DatagenSource",
                "name": "DatagenSourceConnector_0",
                "kafka.auth.mode": "SERVICE_ACCOUNT",
                "kafka.service.account.id": app_connector["id"],
                "kafka.topic": orders["topicName"],
                "output.data.format": "JSON",
                "quickstart": "ORDERS",
                "tasks.max": "1",
            },
            opts = pulumi.ResourceOptions(depends_on=[
                    app_connector_describe_on_cluster,
                    app_connector_write_on_target_topic,
                    app_connector_create_on_data_preview_topics,
                    app_connector_write_on_data_preview_topics,
                ]))
        ```

        ### Example Managed [Amazon S3 Sink Connector](https://docs.confluent.io/cloud/current/connectors/cc-s3-sink.html) that uses a service account to communicate with your Kafka cluster
        ```python
        import pulumi
        import pulumi_confluentcloud as confluentcloud

        # https://github.com/confluentinc/terraform-provider-confluent/tree/master/examples/configurations/connectors/s3-sink-connector
        sink = confluentcloud.Connector("sink",
            environment={
                "id": staging["id"],
            },
            kafka_cluster={
                "id": basic["id"],
            },
            config_sensitive={
                "aws.access.key.id": "***REDACTED***",
                "aws.secret.access.key": "***REDACTED***",
            },
            config_nonsensitive={
                "topics": orders["topicName"],
                "input.data.format": "JSON",
                "connector.class": "S3_SINK",
                "name": "S3_SINKConnector_0",
                "kafka.auth.mode": "SERVICE_ACCOUNT",
                "kafka.service.account.id": app_connector["id"],
                "s3.bucket.name": "<s3-bucket-name>",
                "output.data.format": "JSON",
                "time.interval": "DAILY",
                "flush.size": "1000",
                "tasks.max": "1",
            },
            opts = pulumi.ResourceOptions(depends_on=[
                    app_connector_describe_on_cluster,
                    app_connector_read_on_target_topic,
                    app_connector_create_on_dlq_lcc_topics,
                    app_connector_write_on_dlq_lcc_topics,
                    app_connector_create_on_success_lcc_topics,
                    app_connector_write_on_success_lcc_topics,
                    app_connector_create_on_error_lcc_topics,
                    app_connector_write_on_error_lcc_topics,
                    app_connector_read_on_connect_lcc_group,
                ]))
        ```

        ### Example Managed [Amazon S3 Sink Connector](https://docs.confluent.io/cloud/current/connectors/cc-s3-sink.html) that uses a service account to communicate with your Kafka cluster and IAM Roles for AWS authentication
        ```python
        import pulumi
        import pulumi_confluentcloud as confluentcloud

        # https://github.com/confluentinc/terraform-provider-confluent/tree/master/examples/configurations/connectors/s3-sink-connector-assume-role
        sink = confluentcloud.Connector("sink",
            environment={
                "id": staging["id"],
            },
            kafka_cluster={
                "id": basic["id"],
            },
            config_sensitive={},
            config_nonsensitive={
                "topics": orders["topicName"],
                "input.data.format": "JSON",
                "connector.class": "S3_SINK",
                "name": "S3_SINKConnector_0",
                "kafka.auth.mode": "SERVICE_ACCOUNT",
                "kafka.service.account.id": app_connector["id"],
                "s3.bucket.name": "<s3-bucket-name>",
                "output.data.format": "JSON",
                "time.interval": "DAILY",
                "flush.size": "1000",
                "tasks.max": "1",
                "authentication.method": "IAM Roles",
                "provider.integration.id": main["id"],
            },
            opts = pulumi.ResourceOptions(depends_on=[
                    app_connector_describe_on_cluster,
                    app_connector_read_on_target_topic,
                    app_connector_create_on_dlq_lcc_topics,
                    app_connector_write_on_dlq_lcc_topics,
                    app_connector_create_on_success_lcc_topics,
                    app_connector_write_on_success_lcc_topics,
                    app_connector_create_on_error_lcc_topics,
                    app_connector_write_on_error_lcc_topics,
                    app_connector_read_on_connect_lcc_group,
                    main,
                    s3_access_role,
                ]))
        ```

        ### Example Managed [Amazon DynamoDB Connector](https://docs.confluent.io/cloud/current/connectors/cc-amazon-dynamo-db-sink.html) that uses a service account to communicate with your Kafka cluster
        ```python
        import pulumi
        import pulumi_confluentcloud as confluentcloud

        # https://github.com/confluentinc/terraform-provider-confluent/tree/master/examples/configurations/connectors/dynamo-db-sink-connector
        sink = confluentcloud.Connector("sink",
            environment={
                "id": staging["id"],
            },
            kafka_cluster={
                "id": basic["id"],
            },
            config_sensitive={
                "aws.access.key.id": "***REDACTED***",
                "aws.secret.access.key": "***REDACTED***",
            },
            config_nonsensitive={
                "topics": orders["topicName"],
                "input.data.format": "JSON",
                "connector.class": "DynamoDbSink",
                "name": "DynamoDbSinkConnector_0",
                "kafka.auth.mode": "SERVICE_ACCOUNT",
                "kafka.service.account.id": app_connector["id"],
                "aws.dynamodb.pk.hash": "value.userid",
                "aws.dynamodb.pk.sort": "value.pageid",
                "tasks.max": "1",
            },
            opts = pulumi.ResourceOptions(depends_on=[
                    app_connector_describe_on_cluster,
                    app_connector_read_on_target_topic,
                    app_connector_create_on_dlq_lcc_topics,
                    app_connector_write_on_dlq_lcc_topics,
                    app_connector_create_on_success_lcc_topics,
                    app_connector_write_on_success_lcc_topics,
                    app_connector_create_on_error_lcc_topics,
                    app_connector_write_on_error_lcc_topics,
                    app_connector_read_on_connect_lcc_group,
                ]))
        ```

        ### Example Managed [MySQL Sink Connector](https://docs.confluent.io/cloud/current/connectors/cc-mysql-sink.html) that uses a service account to communicate with your Kafka cluster

        ```python
        import pulumi
        import pulumi_confluentcloud as confluentcloud

        # https://github.com/confluentinc/terraform-provider-confluent/tree/master/examples/configurations/connectors/manage-offsets-source-sink-connector
        sink = confluentcloud.Connector("sink",
            environment={
                "id": staging["id"],
            },
            kafka_cluster={
                "id": basic["id"],
            },
            config_sensitive={
                "connection.password": "***REDACTED***",
            },
            config_nonsensitive={
                "connector.class": "MySqlSink",
                "name": "MySQLSinkConnector_0",
                "topics": orders["topicName"],
                "input.data.format": "AVRO",
                "kafka.auth.mode": "SERVICE_ACCOUNT",
                "kafka.service.account.id": app_connector["id"],
                "db.name": "test_database",
                "connection.user": "confluent_user",
                "connection.host": "dev-testing-temp.abcdefghijk.us-west-7.rds.amazonaws.com",
                "connection.port": "3306",
                "insert.mode": "INSERT",
                "auto.create": "true",
                "auto.evolve": "true",
                "tasks.max": "1",
            },
            offsets=[
                {
                    "partition": {
                        "kafka_partition": "0",
                        "kafka_topic": orders["topicName"],
                    },
                    "offset": {
                        "kafka_offset": "100",
                    },
                },
                {
                    "partition": {
                        "kafka_partition": "1",
                        "kafka_topic": orders["topicName"],
                    },
                    "offset": {
                        "kafka_offset": "200",
                    },
                },
                {
                    "partition": {
                        "kafka_partition": "2",
                        "kafka_topic": orders["topicName"],
                    },
                    "offset": {
                        "kafka_offset": "300",
                    },
                },
            ],
            opts = pulumi.ResourceOptions(depends_on=[
                    app_connector_describe_on_cluster,
                    app_connector_read_on_target_topic,
                    app_connector_create_on_dlq_lcc_topics,
                    app_connector_write_on_dlq_lcc_topics,
                    app_connector_create_on_success_lcc_topics,
                    app_connector_write_on_success_lcc_topics,
                    app_connector_create_on_error_lcc_topics,
                    app_connector_write_on_error_lcc_topics,
                    app_connector_read_on_connect_lcc_group,
                ]))
        ```

        ### Example Custom [Datagen Source Connector](https://www.confluent.io/hub/confluentinc/kafka-connect-datagen) that uses a Kafka API Key to communicate with your Kafka cluster
        ```python
        import pulumi
        import pulumi_confluentcloud as confluentcloud

        # https://github.com/confluentinc/terraform-provider-confluent/tree/master/examples/configurations/connectors/custom-datagen-source-connector
        source = confluentcloud.Connector("source",
            environment={
                "id": staging["id"],
            },
            kafka_cluster={
                "id": basic["id"],
            },
            config_sensitive={
                "kafka.api.key": "***REDACTED***",
                "kafka.api.secret": "***REDACTED***",
            },
            config_nonsensitive={
                "confluent.connector.type": "CUSTOM",
                "connector.class": source_confluent_custom_connector_plugin["connectorClass"],
                "name": "DatagenConnectorExampleName",
                "kafka.auth.mode": "KAFKA_API_KEY",
                "kafka.topic": orders["topicName"],
                "output.data.format": "JSON",
                "quickstart": "ORDERS",
                "confluent.custom.plugin.id": source_confluent_custom_connector_plugin["id"],
                "min.interval": "1000",
                "max.interval": "2000",
                "tasks.max": "1",
            },
            opts = pulumi.ResourceOptions(depends_on=[app_manager_kafka_cluster_admin]))
        ```

        ## Getting Started

        The following end-to-end examples might help to get started with `Connector` resource:
        * `s3-sink-connector`
        * `s3-sink-connector-assume-role`
        * `snowflake-sink-connector`
        * `managed-datagen-source-connector`
        * `elasticsearch-sink-connector`
        * `dynamo-db-sink-connector`
        * `mongo-db-source-connector`
        * `mongo-db-sink-connector`
        * `sql-server-cdc-debezium-source-connector`
        * `postgre-sql-cdc-debezium-source-connector`
        * `custom-datagen-source-connector`
        * `manage-offsets-github-source-connector`
        * `manage-offsets-mongo-db-source-connector`
        * `manage-offsets-mysql-sink-connector`

        > **Note:** Certain connectors require additional ACL entries. See [Additional ACL entries](https://docs.confluent.io/cloud/current/connectors/service-account.html#additional-acl-entries) for more details.

        ## Import

        You can import a connector by using Environment ID, Kafka cluster ID, and connector's name, in the format `<Environment ID>/<Kafka cluster ID>/<Connector name>`, for example:

        $ export CONFLUENT_CLOUD_API_KEY="<cloud_api_key>"

        $ export CONFLUENT_CLOUD_API_SECRET="<cloud_api_secret>"

        ```sh
        $ pulumi import confluentcloud:index/connector:Connector my_connector "env-abc123/lkc-abc123/S3_SINKConnector_0"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] config_nonsensitive: Block for custom *nonsensitive* configuration properties that are *not* labelled with "Type: password" under "Configuration Properties" section in [the docs](https://docs.confluent.io/cloud/current/connectors/index.html):
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] config_sensitive: Block for custom *sensitive* configuration properties that are labelled with "Type: password" under "Configuration Properties" section in [the docs](https://docs.confluent.io/cloud/current/connectors/index.html):
        :param pulumi.Input[Union['ConnectorEnvironmentArgs', 'ConnectorEnvironmentArgsDict']] environment: Environment objects represent an isolated namespace for your Confluent resources for organizational purposes.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ConnectorOffsetArgs', 'ConnectorOffsetArgsDict']]]] offsets: Connector partitions with offsets
        :param pulumi.Input[str] status: The status of the connector (one of `"NONE"`, `"PROVISIONING"`, `"RUNNING"`, `"DEGRADED"`, `"FAILED"`, `"PAUSED"`, `"DELETED"`). Pausing (`"RUNNING" > "PAUSED"`) and resuming (`"PAUSED" > "RUNNING"`) a connector is supported via an update operation.
               
               For more information on connector offset management, see [Manage Offsets for Fully-Managed Connectors in Confluent Cloud](https://docs.confluent.io/cloud/current/connectors/offsets.html).
               
               > **Note:** If there are no _sensitive_ configuration settings for your connector, set `config_sensitive = {}` explicitly.
               
               > **Note:** You may declare sensitive variables for secrets `config_sensitive` block and set them using environment variables (for example, `export TF_VAR_aws_access_key_id="foo"`).
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ConnectorArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        ### Example Managed [Datagen Source Connector](https://docs.confluent.io/cloud/current/connectors/cc-datagen-source.html) that uses a service account to communicate with your Kafka cluster
        ```python
        import pulumi
        import pulumi_confluentcloud as confluentcloud

        # https://github.com/confluentinc/terraform-provider-confluent/tree/master/examples/configurations/connectors/managed-datagen-source-connector
        source = confluentcloud.Connector("source",
            environment={
                "id": staging["id"],
            },
            kafka_cluster={
                "id": basic["id"],
            },
            config_sensitive={},
            config_nonsensitive={
                "connector.class": "DatagenSource",
                "name": "DatagenSourceConnector_0",
                "kafka.auth.mode": "SERVICE_ACCOUNT",
                "kafka.service.account.id": app_connector["id"],
                "kafka.topic": orders["topicName"],
                "output.data.format": "JSON",
                "quickstart": "ORDERS",
                "tasks.max": "1",
            },
            opts = pulumi.ResourceOptions(depends_on=[
                    app_connector_describe_on_cluster,
                    app_connector_write_on_target_topic,
                    app_connector_create_on_data_preview_topics,
                    app_connector_write_on_data_preview_topics,
                ]))
        ```

        ### Example Managed [Amazon S3 Sink Connector](https://docs.confluent.io/cloud/current/connectors/cc-s3-sink.html) that uses a service account to communicate with your Kafka cluster
        ```python
        import pulumi
        import pulumi_confluentcloud as confluentcloud

        # https://github.com/confluentinc/terraform-provider-confluent/tree/master/examples/configurations/connectors/s3-sink-connector
        sink = confluentcloud.Connector("sink",
            environment={
                "id": staging["id"],
            },
            kafka_cluster={
                "id": basic["id"],
            },
            config_sensitive={
                "aws.access.key.id": "***REDACTED***",
                "aws.secret.access.key": "***REDACTED***",
            },
            config_nonsensitive={
                "topics": orders["topicName"],
                "input.data.format": "JSON",
                "connector.class": "S3_SINK",
                "name": "S3_SINKConnector_0",
                "kafka.auth.mode": "SERVICE_ACCOUNT",
                "kafka.service.account.id": app_connector["id"],
                "s3.bucket.name": "<s3-bucket-name>",
                "output.data.format": "JSON",
                "time.interval": "DAILY",
                "flush.size": "1000",
                "tasks.max": "1",
            },
            opts = pulumi.ResourceOptions(depends_on=[
                    app_connector_describe_on_cluster,
                    app_connector_read_on_target_topic,
                    app_connector_create_on_dlq_lcc_topics,
                    app_connector_write_on_dlq_lcc_topics,
                    app_connector_create_on_success_lcc_topics,
                    app_connector_write_on_success_lcc_topics,
                    app_connector_create_on_error_lcc_topics,
                    app_connector_write_on_error_lcc_topics,
                    app_connector_read_on_connect_lcc_group,
                ]))
        ```

        ### Example Managed [Amazon S3 Sink Connector](https://docs.confluent.io/cloud/current/connectors/cc-s3-sink.html) that uses a service account to communicate with your Kafka cluster and IAM Roles for AWS authentication
        ```python
        import pulumi
        import pulumi_confluentcloud as confluentcloud

        # https://github.com/confluentinc/terraform-provider-confluent/tree/master/examples/configurations/connectors/s3-sink-connector-assume-role
        sink = confluentcloud.Connector("sink",
            environment={
                "id": staging["id"],
            },
            kafka_cluster={
                "id": basic["id"],
            },
            config_sensitive={},
            config_nonsensitive={
                "topics": orders["topicName"],
                "input.data.format": "JSON",
                "connector.class": "S3_SINK",
                "name": "S3_SINKConnector_0",
                "kafka.auth.mode": "SERVICE_ACCOUNT",
                "kafka.service.account.id": app_connector["id"],
                "s3.bucket.name": "<s3-bucket-name>",
                "output.data.format": "JSON",
                "time.interval": "DAILY",
                "flush.size": "1000",
                "tasks.max": "1",
                "authentication.method": "IAM Roles",
                "provider.integration.id": main["id"],
            },
            opts = pulumi.ResourceOptions(depends_on=[
                    app_connector_describe_on_cluster,
                    app_connector_read_on_target_topic,
                    app_connector_create_on_dlq_lcc_topics,
                    app_connector_write_on_dlq_lcc_topics,
                    app_connector_create_on_success_lcc_topics,
                    app_connector_write_on_success_lcc_topics,
                    app_connector_create_on_error_lcc_topics,
                    app_connector_write_on_error_lcc_topics,
                    app_connector_read_on_connect_lcc_group,
                    main,
                    s3_access_role,
                ]))
        ```

        ### Example Managed [Amazon DynamoDB Connector](https://docs.confluent.io/cloud/current/connectors/cc-amazon-dynamo-db-sink.html) that uses a service account to communicate with your Kafka cluster
        ```python
        import pulumi
        import pulumi_confluentcloud as confluentcloud

        # https://github.com/confluentinc/terraform-provider-confluent/tree/master/examples/configurations/connectors/dynamo-db-sink-connector
        sink = confluentcloud.Connector("sink",
            environment={
                "id": staging["id"],
            },
            kafka_cluster={
                "id": basic["id"],
            },
            config_sensitive={
                "aws.access.key.id": "***REDACTED***",
                "aws.secret.access.key": "***REDACTED***",
            },
            config_nonsensitive={
                "topics": orders["topicName"],
                "input.data.format": "JSON",
                "connector.class": "DynamoDbSink",
                "name": "DynamoDbSinkConnector_0",
                "kafka.auth.mode": "SERVICE_ACCOUNT",
                "kafka.service.account.id": app_connector["id"],
                "aws.dynamodb.pk.hash": "value.userid",
                "aws.dynamodb.pk.sort": "value.pageid",
                "tasks.max": "1",
            },
            opts = pulumi.ResourceOptions(depends_on=[
                    app_connector_describe_on_cluster,
                    app_connector_read_on_target_topic,
                    app_connector_create_on_dlq_lcc_topics,
                    app_connector_write_on_dlq_lcc_topics,
                    app_connector_create_on_success_lcc_topics,
                    app_connector_write_on_success_lcc_topics,
                    app_connector_create_on_error_lcc_topics,
                    app_connector_write_on_error_lcc_topics,
                    app_connector_read_on_connect_lcc_group,
                ]))
        ```

        ### Example Managed [MySQL Sink Connector](https://docs.confluent.io/cloud/current/connectors/cc-mysql-sink.html) that uses a service account to communicate with your Kafka cluster

        ```python
        import pulumi
        import pulumi_confluentcloud as confluentcloud

        # https://github.com/confluentinc/terraform-provider-confluent/tree/master/examples/configurations/connectors/manage-offsets-source-sink-connector
        sink = confluentcloud.Connector("sink",
            environment={
                "id": staging["id"],
            },
            kafka_cluster={
                "id": basic["id"],
            },
            config_sensitive={
                "connection.password": "***REDACTED***",
            },
            config_nonsensitive={
                "connector.class": "MySqlSink",
                "name": "MySQLSinkConnector_0",
                "topics": orders["topicName"],
                "input.data.format": "AVRO",
                "kafka.auth.mode": "SERVICE_ACCOUNT",
                "kafka.service.account.id": app_connector["id"],
                "db.name": "test_database",
                "connection.user": "confluent_user",
                "connection.host": "dev-testing-temp.abcdefghijk.us-west-7.rds.amazonaws.com",
                "connection.port": "3306",
                "insert.mode": "INSERT",
                "auto.create": "true",
                "auto.evolve": "true",
                "tasks.max": "1",
            },
            offsets=[
                {
                    "partition": {
                        "kafka_partition": "0",
                        "kafka_topic": orders["topicName"],
                    },
                    "offset": {
                        "kafka_offset": "100",
                    },
                },
                {
                    "partition": {
                        "kafka_partition": "1",
                        "kafka_topic": orders["topicName"],
                    },
                    "offset": {
                        "kafka_offset": "200",
                    },
                },
                {
                    "partition": {
                        "kafka_partition": "2",
                        "kafka_topic": orders["topicName"],
                    },
                    "offset": {
                        "kafka_offset": "300",
                    },
                },
            ],
            opts = pulumi.ResourceOptions(depends_on=[
                    app_connector_describe_on_cluster,
                    app_connector_read_on_target_topic,
                    app_connector_create_on_dlq_lcc_topics,
                    app_connector_write_on_dlq_lcc_topics,
                    app_connector_create_on_success_lcc_topics,
                    app_connector_write_on_success_lcc_topics,
                    app_connector_create_on_error_lcc_topics,
                    app_connector_write_on_error_lcc_topics,
                    app_connector_read_on_connect_lcc_group,
                ]))
        ```

        ### Example Custom [Datagen Source Connector](https://www.confluent.io/hub/confluentinc/kafka-connect-datagen) that uses a Kafka API Key to communicate with your Kafka cluster
        ```python
        import pulumi
        import pulumi_confluentcloud as confluentcloud

        # https://github.com/confluentinc/terraform-provider-confluent/tree/master/examples/configurations/connectors/custom-datagen-source-connector
        source = confluentcloud.Connector("source",
            environment={
                "id": staging["id"],
            },
            kafka_cluster={
                "id": basic["id"],
            },
            config_sensitive={
                "kafka.api.key": "***REDACTED***",
                "kafka.api.secret": "***REDACTED***",
            },
            config_nonsensitive={
                "confluent.connector.type": "CUSTOM",
                "connector.class": source_confluent_custom_connector_plugin["connectorClass"],
                "name": "DatagenConnectorExampleName",
                "kafka.auth.mode": "KAFKA_API_KEY",
                "kafka.topic": orders["topicName"],
                "output.data.format": "JSON",
                "quickstart": "ORDERS",
                "confluent.custom.plugin.id": source_confluent_custom_connector_plugin["id"],
                "min.interval": "1000",
                "max.interval": "2000",
                "tasks.max": "1",
            },
            opts = pulumi.ResourceOptions(depends_on=[app_manager_kafka_cluster_admin]))
        ```

        ## Getting Started

        The following end-to-end examples might help to get started with `Connector` resource:
        * `s3-sink-connector`
        * `s3-sink-connector-assume-role`
        * `snowflake-sink-connector`
        * `managed-datagen-source-connector`
        * `elasticsearch-sink-connector`
        * `dynamo-db-sink-connector`
        * `mongo-db-source-connector`
        * `mongo-db-sink-connector`
        * `sql-server-cdc-debezium-source-connector`
        * `postgre-sql-cdc-debezium-source-connector`
        * `custom-datagen-source-connector`
        * `manage-offsets-github-source-connector`
        * `manage-offsets-mongo-db-source-connector`
        * `manage-offsets-mysql-sink-connector`

        > **Note:** Certain connectors require additional ACL entries. See [Additional ACL entries](https://docs.confluent.io/cloud/current/connectors/service-account.html#additional-acl-entries) for more details.

        ## Import

        You can import a connector by using Environment ID, Kafka cluster ID, and connector's name, in the format `<Environment ID>/<Kafka cluster ID>/<Connector name>`, for example:

        $ export CONFLUENT_CLOUD_API_KEY="<cloud_api_key>"

        $ export CONFLUENT_CLOUD_API_SECRET="<cloud_api_secret>"

        ```sh
        $ pulumi import confluentcloud:index/connector:Connector my_connector "env-abc123/lkc-abc123/S3_SINKConnector_0"
        ```

        :param str resource_name: The name of the resource.
        :param ConnectorArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ConnectorArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 config_nonsensitive: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 config_sensitive: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 environment: Optional[pulumi.Input[Union['ConnectorEnvironmentArgs', 'ConnectorEnvironmentArgsDict']]] = None,
                 kafka_cluster: Optional[pulumi.Input[Union['ConnectorKafkaClusterArgs', 'ConnectorKafkaClusterArgsDict']]] = None,
                 offsets: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ConnectorOffsetArgs', 'ConnectorOffsetArgsDict']]]]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ConnectorArgs.__new__(ConnectorArgs)

            if config_nonsensitive is None and not opts.urn:
                raise TypeError("Missing required property 'config_nonsensitive'")
            __props__.__dict__["config_nonsensitive"] = config_nonsensitive
            __props__.__dict__["config_sensitive"] = None if config_sensitive is None else pulumi.Output.secret(config_sensitive)
            if environment is None and not opts.urn:
                raise TypeError("Missing required property 'environment'")
            __props__.__dict__["environment"] = environment
            if kafka_cluster is None and not opts.urn:
                raise TypeError("Missing required property 'kafka_cluster'")
            __props__.__dict__["kafka_cluster"] = kafka_cluster
            __props__.__dict__["offsets"] = offsets
            __props__.__dict__["status"] = status
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["configSensitive"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(Connector, __self__).__init__(
            'confluentcloud:index/connector:Connector',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            config_nonsensitive: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
            config_sensitive: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
            environment: Optional[pulumi.Input[Union['ConnectorEnvironmentArgs', 'ConnectorEnvironmentArgsDict']]] = None,
            kafka_cluster: Optional[pulumi.Input[Union['ConnectorKafkaClusterArgs', 'ConnectorKafkaClusterArgsDict']]] = None,
            offsets: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ConnectorOffsetArgs', 'ConnectorOffsetArgsDict']]]]] = None,
            status: Optional[pulumi.Input[str]] = None) -> 'Connector':
        """
        Get an existing Connector resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] config_nonsensitive: Block for custom *nonsensitive* configuration properties that are *not* labelled with "Type: password" under "Configuration Properties" section in [the docs](https://docs.confluent.io/cloud/current/connectors/index.html):
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] config_sensitive: Block for custom *sensitive* configuration properties that are labelled with "Type: password" under "Configuration Properties" section in [the docs](https://docs.confluent.io/cloud/current/connectors/index.html):
        :param pulumi.Input[Union['ConnectorEnvironmentArgs', 'ConnectorEnvironmentArgsDict']] environment: Environment objects represent an isolated namespace for your Confluent resources for organizational purposes.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ConnectorOffsetArgs', 'ConnectorOffsetArgsDict']]]] offsets: Connector partitions with offsets
        :param pulumi.Input[str] status: The status of the connector (one of `"NONE"`, `"PROVISIONING"`, `"RUNNING"`, `"DEGRADED"`, `"FAILED"`, `"PAUSED"`, `"DELETED"`). Pausing (`"RUNNING" > "PAUSED"`) and resuming (`"PAUSED" > "RUNNING"`) a connector is supported via an update operation.
               
               For more information on connector offset management, see [Manage Offsets for Fully-Managed Connectors in Confluent Cloud](https://docs.confluent.io/cloud/current/connectors/offsets.html).
               
               > **Note:** If there are no _sensitive_ configuration settings for your connector, set `config_sensitive = {}` explicitly.
               
               > **Note:** You may declare sensitive variables for secrets `config_sensitive` block and set them using environment variables (for example, `export TF_VAR_aws_access_key_id="foo"`).
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ConnectorState.__new__(_ConnectorState)

        __props__.__dict__["config_nonsensitive"] = config_nonsensitive
        __props__.__dict__["config_sensitive"] = config_sensitive
        __props__.__dict__["environment"] = environment
        __props__.__dict__["kafka_cluster"] = kafka_cluster
        __props__.__dict__["offsets"] = offsets
        __props__.__dict__["status"] = status
        return Connector(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="configNonsensitive")
    def config_nonsensitive(self) -> pulumi.Output[Mapping[str, str]]:
        """
        Block for custom *nonsensitive* configuration properties that are *not* labelled with "Type: password" under "Configuration Properties" section in [the docs](https://docs.confluent.io/cloud/current/connectors/index.html):
        """
        return pulumi.get(self, "config_nonsensitive")

    @property
    @pulumi.getter(name="configSensitive")
    def config_sensitive(self) -> pulumi.Output[Mapping[str, str]]:
        """
        Block for custom *sensitive* configuration properties that are labelled with "Type: password" under "Configuration Properties" section in [the docs](https://docs.confluent.io/cloud/current/connectors/index.html):
        """
        return pulumi.get(self, "config_sensitive")

    @property
    @pulumi.getter
    def environment(self) -> pulumi.Output['outputs.ConnectorEnvironment']:
        """
        Environment objects represent an isolated namespace for your Confluent resources for organizational purposes.
        """
        return pulumi.get(self, "environment")

    @property
    @pulumi.getter(name="kafkaCluster")
    def kafka_cluster(self) -> pulumi.Output['outputs.ConnectorKafkaCluster']:
        return pulumi.get(self, "kafka_cluster")

    @property
    @pulumi.getter
    def offsets(self) -> pulumi.Output[Optional[Sequence['outputs.ConnectorOffset']]]:
        """
        Connector partitions with offsets
        """
        return pulumi.get(self, "offsets")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        The status of the connector (one of `"NONE"`, `"PROVISIONING"`, `"RUNNING"`, `"DEGRADED"`, `"FAILED"`, `"PAUSED"`, `"DELETED"`). Pausing (`"RUNNING" > "PAUSED"`) and resuming (`"PAUSED" > "RUNNING"`) a connector is supported via an update operation.

        For more information on connector offset management, see [Manage Offsets for Fully-Managed Connectors in Confluent Cloud](https://docs.confluent.io/cloud/current/connectors/offsets.html).

        > **Note:** If there are no _sensitive_ configuration settings for your connector, set `config_sensitive = {}` explicitly.

        > **Note:** You may declare sensitive variables for secrets `config_sensitive` block and set them using environment variables (for example, `export TF_VAR_aws_access_key_id="foo"`).
        """
        return pulumi.get(self, "status")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetClusterLinkResult',
    'AwaitableGetClusterLinkResult',
    'get_cluster_link',
    'get_cluster_link_output',
]

@pulumi.output_type
class GetClusterLinkResult:
    """
    A collection of values returned by getClusterLink.
    """
    def __init__(__self__, cluster_link_id=None, config=None, credentials=None, id=None, kafka_cluster=None, link_name=None, link_state=None, rest_endpoint=None):
        if cluster_link_id and not isinstance(cluster_link_id, str):
            raise TypeError("Expected argument 'cluster_link_id' to be a str")
        pulumi.set(__self__, "cluster_link_id", cluster_link_id)
        if config and not isinstance(config, dict):
            raise TypeError("Expected argument 'config' to be a dict")
        pulumi.set(__self__, "config", config)
        if credentials and not isinstance(credentials, dict):
            raise TypeError("Expected argument 'credentials' to be a dict")
        pulumi.set(__self__, "credentials", credentials)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if kafka_cluster and not isinstance(kafka_cluster, dict):
            raise TypeError("Expected argument 'kafka_cluster' to be a dict")
        pulumi.set(__self__, "kafka_cluster", kafka_cluster)
        if link_name and not isinstance(link_name, str):
            raise TypeError("Expected argument 'link_name' to be a str")
        pulumi.set(__self__, "link_name", link_name)
        if link_state and not isinstance(link_state, str):
            raise TypeError("Expected argument 'link_state' to be a str")
        pulumi.set(__self__, "link_state", link_state)
        if rest_endpoint and not isinstance(rest_endpoint, str):
            raise TypeError("Expected argument 'rest_endpoint' to be a str")
        pulumi.set(__self__, "rest_endpoint", rest_endpoint)

    @property
    @pulumi.getter(name="clusterLinkId")
    def cluster_link_id(self) -> str:
        """
        (Required String) The actual Cluster Link ID assigned from Confluent Cloud that uniquely represents a link between two Kafka clusters, for example, `qz0HDEV-Qz2B5aPFpcWQJQ`.
        """
        return pulumi.get(self, "cluster_link_id")

    @property
    @pulumi.getter
    def config(self) -> Mapping[str, str]:
        """
        (Optional Map) The custom cluster link settings retrieved:
        """
        return pulumi.get(self, "config")

    @property
    @pulumi.getter
    def credentials(self) -> Optional['outputs.GetClusterLinkCredentialsResult']:
        return pulumi.get(self, "credentials")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        (Required String) The composite ID of the Cluster Link data-source, in the format `<Kafka cluster ID>/<Cluster link name>`, for example, `lkc-abc123/my-cluster-link`.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="kafkaCluster")
    def kafka_cluster(self) -> Optional['outputs.GetClusterLinkKafkaClusterResult']:
        return pulumi.get(self, "kafka_cluster")

    @property
    @pulumi.getter(name="linkName")
    def link_name(self) -> str:
        return pulumi.get(self, "link_name")

    @property
    @pulumi.getter(name="linkState")
    def link_state(self) -> str:
        """
        (Required String) The current state of the Cluster Link.
        """
        return pulumi.get(self, "link_state")

    @property
    @pulumi.getter(name="restEndpoint")
    def rest_endpoint(self) -> Optional[str]:
        return pulumi.get(self, "rest_endpoint")


class AwaitableGetClusterLinkResult(GetClusterLinkResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetClusterLinkResult(
            cluster_link_id=self.cluster_link_id,
            config=self.config,
            credentials=self.credentials,
            id=self.id,
            kafka_cluster=self.kafka_cluster,
            link_name=self.link_name,
            link_state=self.link_state,
            rest_endpoint=self.rest_endpoint)


def get_cluster_link(credentials: Optional[Union['GetClusterLinkCredentialsArgs', 'GetClusterLinkCredentialsArgsDict']] = None,
                     kafka_cluster: Optional[Union['GetClusterLinkKafkaClusterArgs', 'GetClusterLinkKafkaClusterArgsDict']] = None,
                     link_name: Optional[str] = None,
                     rest_endpoint: Optional[str] = None,
                     opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetClusterLinkResult:
    """
    [![General Availability](https://img.shields.io/badge/Lifecycle%20Stage-General%20Availability-%2345c6e8)](https://docs.confluent.io/cloud/current/api.html#section/Versioning/API-Lifecycle-Policy)

    `ClusterLink` describes a Cluster Link data source.

    ## Example Usage

    ### Option #1: Manage multiple Kafka clusters in the same Pulumi Stack

    ```python
    import pulumi
    import pulumi_confluentcloud as confluentcloud

    main = confluentcloud.get_cluster_link(link_name="main-link",
        rest_endpoint=west["restEndpoint"],
        kafka_cluster={
            "id": west["id"],
        },
        credentials={
            "key": app_manager_west_cluster_api_key["id"],
            "secret": app_manager_west_cluster_api_key["secret"],
        })
    pulumi.export("kafkaClusterLinkId", main.cluster_link_id)
    ```

    ### Option #2: Manage a single Kafka cluster in the same Pulumi Stack

    ```python
    import pulumi
    import pulumi_confluentcloud as confluentcloud

    main = confluentcloud.get_cluster_link(link_name="main-link")
    pulumi.export("kafkaClusterLinkId", main.cluster_link_id)
    ```


    :param str link_name: The name of the cluster link, for example, `my-cluster-link`.
    :param str rest_endpoint: The REST endpoint of the Kafka cluster, for example, `https://pkc-00000.us-central1.gcp.confluent.cloud:443`).
    """
    __args__ = dict()
    __args__['credentials'] = credentials
    __args__['kafkaCluster'] = kafka_cluster
    __args__['linkName'] = link_name
    __args__['restEndpoint'] = rest_endpoint
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('confluentcloud:index/getClusterLink:getClusterLink', __args__, opts=opts, typ=GetClusterLinkResult).value

    return AwaitableGetClusterLinkResult(
        cluster_link_id=pulumi.get(__ret__, 'cluster_link_id'),
        config=pulumi.get(__ret__, 'config'),
        credentials=pulumi.get(__ret__, 'credentials'),
        id=pulumi.get(__ret__, 'id'),
        kafka_cluster=pulumi.get(__ret__, 'kafka_cluster'),
        link_name=pulumi.get(__ret__, 'link_name'),
        link_state=pulumi.get(__ret__, 'link_state'),
        rest_endpoint=pulumi.get(__ret__, 'rest_endpoint'))
def get_cluster_link_output(credentials: Optional[pulumi.Input[Optional[Union['GetClusterLinkCredentialsArgs', 'GetClusterLinkCredentialsArgsDict']]]] = None,
                            kafka_cluster: Optional[pulumi.Input[Optional[Union['GetClusterLinkKafkaClusterArgs', 'GetClusterLinkKafkaClusterArgsDict']]]] = None,
                            link_name: Optional[pulumi.Input[str]] = None,
                            rest_endpoint: Optional[pulumi.Input[Optional[str]]] = None,
                            opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetClusterLinkResult]:
    """
    [![General Availability](https://img.shields.io/badge/Lifecycle%20Stage-General%20Availability-%2345c6e8)](https://docs.confluent.io/cloud/current/api.html#section/Versioning/API-Lifecycle-Policy)

    `ClusterLink` describes a Cluster Link data source.

    ## Example Usage

    ### Option #1: Manage multiple Kafka clusters in the same Pulumi Stack

    ```python
    import pulumi
    import pulumi_confluentcloud as confluentcloud

    main = confluentcloud.get_cluster_link(link_name="main-link",
        rest_endpoint=west["restEndpoint"],
        kafka_cluster={
            "id": west["id"],
        },
        credentials={
            "key": app_manager_west_cluster_api_key["id"],
            "secret": app_manager_west_cluster_api_key["secret"],
        })
    pulumi.export("kafkaClusterLinkId", main.cluster_link_id)
    ```

    ### Option #2: Manage a single Kafka cluster in the same Pulumi Stack

    ```python
    import pulumi
    import pulumi_confluentcloud as confluentcloud

    main = confluentcloud.get_cluster_link(link_name="main-link")
    pulumi.export("kafkaClusterLinkId", main.cluster_link_id)
    ```


    :param str link_name: The name of the cluster link, for example, `my-cluster-link`.
    :param str rest_endpoint: The REST endpoint of the Kafka cluster, for example, `https://pkc-00000.us-central1.gcp.confluent.cloud:443`).
    """
    __args__ = dict()
    __args__['credentials'] = credentials
    __args__['kafkaCluster'] = kafka_cluster
    __args__['linkName'] = link_name
    __args__['restEndpoint'] = rest_endpoint
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('confluentcloud:index/getClusterLink:getClusterLink', __args__, opts=opts, typ=GetClusterLinkResult)
    return __ret__.apply(lambda __response__: GetClusterLinkResult(
        cluster_link_id=pulumi.get(__response__, 'cluster_link_id'),
        config=pulumi.get(__response__, 'config'),
        credentials=pulumi.get(__response__, 'credentials'),
        id=pulumi.get(__response__, 'id'),
        kafka_cluster=pulumi.get(__response__, 'kafka_cluster'),
        link_name=pulumi.get(__response__, 'link_name'),
        link_state=pulumi.get(__response__, 'link_state'),
        rest_endpoint=pulumi.get(__response__, 'rest_endpoint')))
